import { QuintEx } from './ir/quintIr';
import { Rng } from './rng';
import { QuintError } from './quintError';
/**
 * Various settings that have to be passed to the simulator to run.
 */
export interface SimulatorOptions {
    init: string;
    step: string;
    invariant: string;
    maxSamples: number;
    maxSteps: number;
    numberOfTraces: number;
    rng: Rng;
    verbosity: number;
    storeMetadata: boolean;
    onTrace(index: number, status: string, vars: string[], states: QuintEx[]): void;
}
export interface SimulationTrace {
    states: QuintEx[];
    result: boolean;
    seed: bigint;
}
export type SimulationStatus = 'ok' | 'violation' | 'error';
/** The outcome of a simulation
 */
export interface Outcome {
    status: SimulationStatus;
    errors: QuintError[];
    bestTraces: SimulationTrace[];
    witnessingTraces: number[];
    samples: number;
}
/**
 * A result returned by the simulator.
 */
export interface SimulationResult {
    result: QuintEx;
    witnessingTraces: number[];
    samples: number;
}
